@@ -1,7 +1,7 @@
 from cffi import FFI
 
 ffibuilder = FFI()
-ffibuilder.set_source("_jack", None)
+ffibuilder.set_source('_jack', None)
 ffibuilder.cdef("""
 
 /* types.h */
@@ -141,7 +141,8 @@ const char** jack_port_get_connections(const jack_port_t* port);
 const char** jack_port_get_all_connections(const jack_client_t* client, const jack_port_t* port);
 /* deprecated: jack_port_tie */
 /* deprecated: jack_port_untie */
-int jack_port_set_name(jack_port_t* port, const char* port_name);
+int jack_port_set_name(jack_port_t* port, const char* port_name); /* deprecated */
+int jack_port_rename(jack_client_t* client, jack_port_t* port, const char* port_name);
 int jack_port_set_alias(jack_port_t *port, const char *alias);
 int jack_port_unset_alias(jack_port_t *port, const char *alias);
 int jack_port_get_aliases(const jack_port_t * port, char *const aliases[2]);
@@ -208,7 +209,7 @@ size_t jack_ringbuffer_write_space(const jack_ringbuffer_t* rb);
 
 /* transport.h */
 
-/* TODO: jack_release_timebase */
+int jack_release_timebase(jack_client_t* client);
 int jack_set_sync_callback(jack_client_t* client, JackSyncCallback sync_callback, void* arg);
 int jack_set_sync_timeout(jack_client_t* client, jack_time_t timeout);
 int jack_set_timebase_callback(jack_client_t* client, int conditional, JackTimebaseCallback timebase_callback, void* arg);
@@ -316,5 +317,5 @@ struct _jack_position {
 };
 """, packed=True)
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     ffibuilder.compile(verbose=True)
